@@ -10,7 +10,7 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import division, absolute_import
+from __future__ import division, absolute_import, print_function, unicode_literals
 import posixpath
 
 from creole.shared.base_emitter import BaseEmitter
@@ -36,13 +36,13 @@ class CreoleEmitter(BaseEmitter):
 
     def blockdata_pre_emit(self, node):
         """ pre block -> with newline at the end """
-        return u"{{{%s}}}\n" % self.deentity.replace_all(node.content)
+        return "{{{%s}}}\n" % self.deentity.replace_all(node.content)
     def inlinedata_pre_emit(self, node):
         """ a pre inline block -> no newline at the end """
-        return u"{{{%s}}}" % self.deentity.replace_all(node.content)
+        return "{{{%s}}}" % self.deentity.replace_all(node.content)
 
     def blockdata_pass_emit(self, node):
-        return u"%s\n\n" % node.content
+        return "%s\n\n" % node.content
         return node.content
 
     #--------------------------------------------------------------------------
@@ -55,12 +55,12 @@ class CreoleEmitter(BaseEmitter):
 
     def br_emit(self, node):
         if self._inner_list != "":
-            return u"\\\\"
+            return "\\\\"
         else:
-            return u"\n"
+            return "\n"
 
     def headline_emit(self, node):
-        return u"%s %s\n\n" % (u"=" * node.level, self.emit_children(node))
+        return "%s %s\n\n" % ("=" * node.level, self.emit_children(node))
 
     #--------------------------------------------------------------------------
 
@@ -90,21 +90,25 @@ class CreoleEmitter(BaseEmitter):
     #--------------------------------------------------------------------------
 
     def hr_emit(self, node):
-        return u"----\n\n"
+        return "----\n\n"
 
     def a_emit(self, node):
         link_text = self.emit_children(node)
-        url = node.attrs["href"]
+        try:
+            url = node.attrs["href"]
+        except KeyError:
+            # e.g.: <a name="anchor-one">foo</a>
+            return link_text
         if link_text == url:
-            return u"[[%s]]" % url
+            return "[[%s]]" % url
         else:
-            return u"[[%s|%s]]" % (url, link_text)
+            return "[[%s|%s]]" % (url, link_text)
 
     def img_emit(self, node):
         src = node.attrs["src"]
 
         if src.split(':')[0] == 'data':
-            return u""
+            return ""
 
         title = node.attrs.get("title", "")
         alt = node.attrs.get("alt", "")
@@ -116,7 +120,7 @@ class CreoleEmitter(BaseEmitter):
         if text == "": # Use filename as picture text
             text = posixpath.basename(src)
 
-        return u"{{%s|%s}}" % (src, text)
+        return "{{%s|%s}}" % (src, text)
 
     #--------------------------------------------------------------------------
 
@@ -141,40 +145,28 @@ class CreoleEmitter(BaseEmitter):
 
 if __name__ == '__main__':
     import doctest
-    print doctest.testmod()
+    print(doctest.testmod())
 
 #    import sys;sys.exit()
     from creole.html_parser.parser import HtmlParser
 
-    data = u"""
-<ul>
-    <li><p>item 1</p>
-        <ul>
-            <li><p>subsubitem 1.1.1</p></li>
-            <li>subsubitem 1.1.2</li>
-        </ul>
-    </li>
-    <li><p>item 2</p>
-        <ul>
-            <li>subitem 2.1</li>
-        </ul>
-    </li>
-</ul>
+    data = """A <<test_macro1 args="foo1">>bar1<</test_macro1>> in a line..."""
 
-"""
-
-#    print data.strip()
+#    print(data.strip())
     h2c = HtmlParser(
         debug=True
     )
     document_tree = h2c.feed(data)
     h2c.debug()
 
+    from creole.shared.unknown_tags import escape_unknown_nodes
+
     e = CreoleEmitter(document_tree,
-        debug=True
+        debug=True,
+        unknown_emit=escape_unknown_nodes
     )
     content = e.emit()
-    print "*" * 79
-    print content
-    print "*" * 79
-    print content.replace(" ", ".").replace("\n", "\\n\n")
+    print("*" * 79)
+    print(content)
+    print("*" * 79)
+    print(content.replace(" ", ".").replace("\n", "\\n\n"))
