@@ -10,7 +10,7 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import division, absolute_import
+from __future__ import division, absolute_import, print_function, unicode_literals
 import posixpath
 
 from creole.shared.base_emitter import BaseEmitter
@@ -37,23 +37,23 @@ class TextileEmitter(BaseEmitter):
 
     def blockdata_pre_emit(self, node):
         """ pre block -> with newline at the end """
-        return u"<pre>%s</pre>\n" % self.deentity.replace_all(node.content)
+        return "<pre>%s</pre>\n" % self.deentity.replace_all(node.content)
     def inlinedata_pre_emit(self, node):
         """ a pre inline block -> no newline at the end """
-        return u"<pre>%s</pre>" % self.deentity.replace_all(node.content)
+        return "<pre>%s</pre>" % self.deentity.replace_all(node.content)
 
     def blockdata_pass_emit(self, node):
-        return u"%s\n\n" % node.content
+        return "%s\n\n" % node.content
         return node.content
 
 
     #--------------------------------------------------------------------------
 
     def p_emit(self, node):
-        return u"%s\n\n" % self.emit_children(node)
+        return "%s\n\n" % self.emit_children(node)
 
     def headline_emit(self, node):
-        return u"h%i. %s\n\n" % (node.level, self.emit_children(node))
+        return "h%i. %s\n\n" % (node.level, self.emit_children(node))
 
     #--------------------------------------------------------------------------
 
@@ -91,18 +91,18 @@ class TextileEmitter(BaseEmitter):
     #--------------------------------------------------------------------------
 
     def hr_emit(self, node):
-        return u"----\n\n"
+        return "----\n\n"
 
     def a_emit(self, node):
         link_text = self.emit_children(node)
         url = node.attrs["href"]
-        return u'"%s":%s' % (link_text, url)
+        return '"%s":%s' % (link_text, url)
 
     def img_emit(self, node):
         src = node.attrs["src"]
 
         if src.split(':')[0] == 'data':
-            return u""
+            return ""
 
         title = node.attrs.get("title", "")
         alt = node.attrs.get("alt", "")
@@ -114,7 +114,7 @@ class TextileEmitter(BaseEmitter):
         if text == "": # Use filename as picture text
             text = posixpath.basename(src)
 
-        return u"!%s(%s)!" % (src, text)
+        return "!%s(%s)!" % (src, text)
 
     #--------------------------------------------------------------------------
 
@@ -133,12 +133,12 @@ class TextileEmitter(BaseEmitter):
 
 if __name__ == '__main__':
     import doctest
-    print doctest.testmod()
+    print(doctest.testmod())
 
 #    import sys;sys.exit()
     from creole.html_parser.parser import HtmlParser
 
-    data = u"""
+    data = """
 <h1>Textile</h1>
 <table>
 <tr>
@@ -152,7 +152,7 @@ if __name__ == '__main__':
 </table>
 """
 
-#    print data.strip()
+#    print(data.strip())
     h2c = HtmlParser(
         debug=True
     )
@@ -163,7 +163,7 @@ if __name__ == '__main__':
         debug=True
     )
     content = e.emit()
-    print "*" * 79
-    print content
-    print "*" * 79
-    print content.replace(" ", ".").replace("\n", "\\n\n")
+    print("*" * 79)
+    print(content)
+    print("*" * 79)
+    print(content.replace(" ", ".").replace("\n", "\\n\n"))
