@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-
 """
     python-creole utils
     ~~~~~~~~~~~~~~~~~~~    
@@ -11,10 +10,15 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import division, absolute_import
+from __future__ import division, absolute_import, print_function, unicode_literals
 
 import re
-import htmlentitydefs
+try:
+    import htmlentitydefs as entities
+except ImportError:
+    from html import entities # python 3
+
+from creole.py3compat import PY3
 
 
 entities_rules = '|'.join([
@@ -22,7 +26,7 @@ entities_rules = '|'.join([
     r"(&\#x(?P<hex>[a-fA-F0-9]+);)",
     r"(&(?P<named>[a-zA-Z]+);)",
 ])
-#print entities_rules
+#print(entities_rules)
 entities_regex = re.compile(
     entities_rules, re.VERBOSE | re.UNICODE | re.MULTILINE
 )
@@ -33,44 +37,52 @@ class Deentity(object):
     replace html entity
 
     >>> d = Deentity()
-    >>> d.replace_all(u"-=[&nbsp;&gt;&#62;&#x3E;nice&lt;&#60;&#x3C;&nbsp;]=-")
-    u'-=[ >>>nice<<< ]=-'
+    >>> d.replace_all("-=[&nbsp;&gt;&#62;&#x3E;nice&lt;&#60;&#x3C;&nbsp;]=-")
+    '-=[ >>>nice<<< ]=-'
         
-    >>> d.replace_all(u"-=[M&uuml;hlheim]=-") # uuml - latin small letter u with diaeresis
-    u'-=[M\\xfchlheim]=-'
+    >>> d.replace_all("-=[M&uuml;hlheim]=-") # uuml - latin small letter u with diaeresis
+    '-=[M\\xfchlheim]=-'
 
     >>> d.replace_number("126")
-    u'~'
+    '~'
     >>> d.replace_hex("7E")
-    u'~'
+    '~'
     >>> d.replace_named("amp")
-    u'&'
+    '&'
     """
     def replace_number(self, text):
         """ unicode number entity """
         unicode_no = int(text)
-        return unichr(unicode_no)
+        if PY3:
+            return chr(unicode_no)
+        else:
+            return unichr(unicode_no)
 
     def replace_hex(self, text):
         """ hex entity """
         unicode_no = int(text, 16)
-        return unichr(unicode_no)
+        if PY3:
+            return chr(unicode_no)
+        else:
+            return unichr(unicode_no)
 
     def replace_named(self, text):
         """ named entity """
         if text == "nbsp":
             # Non breaking spaces is not in htmlentitydefs
-            return u" "
+            return " "
         else:
-            codepoint = htmlentitydefs.name2codepoint[text]
-            character = unichr(codepoint)
-            return character
+            codepoint = entities.name2codepoint[text]
+            if PY3:
+                return chr(codepoint)
+            else:
+                return unichr(codepoint)
 
     def replace_all(self, content):
         """ replace all html entities form the given text. """
         def replace_entity(match):
             groups = match.groupdict()
-            for name, text in groups.iteritems():
+            for name, text in groups.items():
                 if text is not None:
                     replace_method = getattr(self, 'replace_%s' % name)
                     return replace_method(text)
@@ -83,4 +95,4 @@ class Deentity(object):
 
 if __name__ == '__main__':
     import doctest
-    print doctest.testmod()
+    print(doctest.testmod())
