@@ -101,4 +101,4 @@ class MarkupTable(object):
 
 if __name__ == '__main__':
     import doctest
-    print doctest.testmod()
+    print(doctest.testmod())
