@@ -7,7 +7,7 @@
     
     https://code.google.com/p/python-creole/wiki/UseInSetup
 
-    :copyleft: 2011 by python-creole team, see AUTHORS for more details.
+    :copyleft: 2011-2012 by python-creole team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
@@ -20,6 +20,7 @@ import creole
 from creole.setup_utils import get_long_description
 from creole.tests.utils.base_unittest import BaseCreoleTest
 from creole.py3compat import BINARY_TYPE, PY3, TEXT_TYPE
+import tempfile
 
 
 CREOLE_PACKAGE_ROOT = os.path.abspath(os.path.join(os.path.dirname(creole.__file__), ".."))
@@ -51,6 +52,36 @@ class SetupUtilsTests(BaseCreoleTest):
         long_description = get_long_description(CREOLE_PACKAGE_ROOT, raise_errors=True)
         self.assertIn("=====\nabout\n=====\n\n", long_description)
 
+    def _tempfile(self, content):
+        fd = tempfile.NamedTemporaryFile()
+        path, filename = os.path.split(fd.name)
+
+        fd.write(content)
+        fd.seek(0)
+        return path, filename, fd
+
+    def test_tempfile_without_error(self):
+        path, filename, fd = self._tempfile(b"== noerror ==")
+        try:
+            long_description = get_long_description(path, filename, raise_errors=True)
+            self.assertEqual(long_description, "-------\nnoerror\n-------")
+        finally:
+            fd.close()
+            
+    def test_get_long_description_error_handling(self):
+        """
+        Test if get_long_description will raised a error, if description
+        produce a ReSt error.
+        
+        We test with this error:
+        <string>:102: (ERROR/3) Document or section may not begin with a transition.
+        """
+        path, filename, fd = self._tempfile(b"----")
+        try:
+            self.assertRaises(SystemExit, get_long_description, path, filename, raise_errors=True)
+        finally:
+            fd.close()
+
     def test_wrong_path_without_raise_errors(self):
         self.assertEqual(
             get_long_description("wrong/path", raise_errors=False).replace("u'", "'"),
